/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
Sonatype.repoServer.m2SearchPanelClass = function(config) {
  var config = config || {};
  var defaultConfig = {};
  Ext.apply(this, config, defaultConfig);

  this.url = Sonatype.config.servicePath + '/search/m2/class';

  var detailViewTpl = new Ext.XTemplate(['<h2>Artifact Detail View</h3>', '<div class="result-item">', '<ul>', '<li>groupId:{groupId:htmlEncode}</li>', '<li>artifactId:{artifactId:htmlEncode}</li>', '<li>version:{version:htmlEncode}</li>',
      '<li>jarUrl:{jarUrl:htmlEncode}</li>', '</ul>', '</div>']);

  // render event handler config that overrides <a/> click events
  var linkInterceptor = {
    render : function(p) {
      p.body.on({
            'mousedown' : function(e, t) { // try to intercept the easy way
              t.target = '_blank';
            },
            'click' : function(e, t) { // if they tab + enter a link, need to
                                        // do it old fashioned way
              if (String(t.target).toLowerCase() != '_blank')
              {
                e.stopEvent();
                Sonatype.utils.openWindow(t.href);
              }
            },
            delegate : 'a'
          });
    }
  };

  this.grid = new Sonatype.repoServer.m2SearchResultGrid({
        searchPanel : this
      });

  this.appletPanel = new Ext.Panel({
        fieldLabel : '',
        html : '<div style="width:10px"></div>'
      });

  this.searchToolbar = new Ext.Toolbar({
        ctCls : 'search-all-tbar',
        items : ['Class Name:', this.classField = new Ext.app.SearchField({
                  xtype : 'nexussearchfield',
                  id : 'search-all-field',
                  paramName : 'cn',
                  searchPanel : this,
                  width : 300
                })]
      });

  this.artifactInformationPanel = new Sonatype.repoServer.m2InformationPanel({});

  Sonatype.repoServer.m2SearchPanelClass.superclass.constructor.call(this, {
        layout : 'border',
        hideMode : 'offsets',
        tbar : this.searchToolbar,
        items : [this.grid, this.artifactInformationPanel]
      });

  this.on({
        'render' : function() {
          this.classField.focus();
        },
        scope : this
      });

  this.grid.getSelectionModel().on('rowselect', this.displayArtifactInformation, this);
  this.grid.clearButton.on('click', this.clearArtifactInformation, this);
};

// @todo: generalize this search panel for other ST servers to use by providing
// their own store & reader
Ext.extend(Sonatype.repoServer.m2SearchPanelClass, Ext.Panel, {

      clearArtifactInformation : function(button, e) {
        this.artifactInformationPanel.showArtifact({
              groupId : '',
              artifactId : '',
              version : ''
            }, true);
      },

      displayArtifactInformation : function(selectionModel, index, rec) {
        this.artifactInformationPanel.showArtifact(rec.data);
      },

      fetchFirst50 : function(p) {
        p.artifactInformationPanel.collapse();
        p.grid.totalRecords = 0;
        p.grid.store.load({
              params : {
                from : 0,
                count : 50
              }
            });
      },

      applyBookmark : function(bookmark) {},

      getBookmark : function() {},

      setWarningLabel : function(s) {
        this.clearWarningLabel();
        this.warningLabel = this.searchToolbar.addText('<span class="x-toolbar-warning">' + s + '</span>');
      },

      clearWarningLabel : function() {
        if (this.warningLabel)
        {
          this.warningLabel.destroy();
          this.warningLabel = null;
        }
      },

      startSearch : function() {
        this.grid.store.baseParams = {};

        if (this.classField.getRawValue())
        {
          this.grid.store.baseParams['c'] = this.classField.getRawValue();
        }

        if (this.grid.store.baseParams['c'] == null)
        {

          this.setWarningLabel('A class name is required to run a search.');
          return;
        }
        this.clearWarningLabel();

        this.fetchFirst50(this);
      },

      onEnterPressed : function(f, e) {
        if (e.getKey() == e.ENTER)
        {
          this.startSearch();
        }
      }

    });

Sonatype.Events.addListener('nexusNavigationInit', function(nexusPanel) {
      nexusPanel.add({
            enabled : Sonatype.lib.Permissions.checkPermission('nexus:index', Sonatype.lib.Permissions.READ),
            sectionId : 'st-nexus-search',
            title : 'Maven Class Search',
            tabTitle : 'Maven Class Search',
            tabId : 'nexus-m2-class-search',
            tabCode : Sonatype.repoServer.m2SearchPanelClass
          });
    });
