/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX, Ext, Nexus*/

/**
 * Shows the current activity for a staging repository.
 *
 * @since 2.3
 */
NX.define('Nexus.staging.repository.activity.ActivityView', {
    extend: 'Ext.Panel',

    mixins: [
        'Nexus.LogAwareMixin'
    ],

    requires: [
        'Nexus.staging.Icons',
        'Nexus.staging.repository.activity.ActivityTreeLoader',
        'Nexus.staging.repository.activity.DetailManager'
    ],

    /**
     * @override
     */
    initComponent: function () {
        var self = this;

        self.treeLoader = NX.create('Nexus.staging.repository.activity.ActivityTreeLoader');

        self.treePanel = NX.create('Ext.tree.TreePanel', {
            cls: 'nx-staging-repository-ActivityView-treePanel',
            border: false,
            region: 'center',
            minWidth: 100,
            autoScroll: true,

            loader: self.treeLoader,
            root: self.treeLoader.createRootNode(),
            rootVisible: false,

            listeners: {
                click: function(node) {
                    self.nodeSelected(node);
                }
            }
        });
        
        self.messagePanel = NX.create('Ext.Panel', {
            cls: 'nx-staging-repository-ActivityView-messagePanel',
            border: false,
            region: 'east',
            minWidth: 100,
            width: '50%',
            split: true,
            collapsed: true,
            collapseMode: 'mini',
            autoScroll: true
        });

        Ext.apply(self, {
            cls: 'nx-staging-repository-ActivityView',
            title: 'Activity',
            border: false,
            layout: 'border',
            items: [
                self.treePanel,
                self.messagePanel
            ]
        });

        self.constructor.superclass.initComponent.apply(self, arguments);
    },

    /**
     * @private
     */
    hideMessagePanel: function () {
        var self = this;
        self.messagePanel.collapse(false);
        self.messagePanel.hide();

        // HACK: Avoid ugly think black bar where collapse tool would have been rendered
        self.doLayout();
    },

    /**
     * @private
     */
    showMessagePanel: function () {
        var self = this;
        self.messagePanel.show();
        self.messagePanel.expand(false);
    },

    /**
     * Node selected, update message panel details.
     *
     * @private
     */
    nodeSelected: function(node) {
        var self = this,
            data = node.attributes.data,
            dataType = node.attributes.dataType,
            detail;

        self.logDebug('Selected:', dataType, node.id, node.text);

        switch (dataType) {
            case 'activity':
                detail = Nexus.staging.repository.activity.DetailManager.forActivity(data);
                break;

            case 'event':
                detail = Nexus.staging.repository.activity.DetailManager.forEvent(data);
                break;

            case 'root':
            case 'repository':
            case 'empty':
                // ignore these types and hide the message panel
                self.hideMessagePanel();
                return;

            default:
                self.logWarn('Unsupported dataType:', dataType);
        }

        // render template
        detail.getTemplate().overwrite(self.messagePanel.body, {
            detail: detail,
            data: data
        });

        self.showMessagePanel();
    },

    /**
     * Update view from record.
     *
     * @param repo
     */
    updateRecord: function (repo) {
        var self = this,
            root,
            node;

        node = self.treeLoader.createRepositoryNode(repo);
        root = self.treePanel.getRootNode();
        root.removeAll(true);
        root.appendChild(node);

        self.hideMessagePanel();
    }
});
