/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/**
 * User-token user-profile view.
 *
 * @class Nexus.usertoken.UserProfileView
 * @extends Ext.Panel
 * @namespace Nexus.usertoken
 */
Ext.define('Nexus.usertoken.UserProfileView', {
    extend: 'Ext.Panel',
    requires: ['Nexus.usertoken.AuthenticateButton', 'Nexus.usertoken.UserTokenWindow', 'Nexus.Image'],
    requirejs: ['Nexus/usertoken'],
    mixins: [
      'Nexus.LogAwareMixin'
    ],

    constructor: function (config) {
        var self = this;

        Ext.apply(self, {
            cls: 'nx-usertoken-UserProfileView',
            border: false,
            items: [
                {
                    xtype: 'image',
                    cls: 'nx-usertoken-icon',
                    src: Nexus.usertoken.iconPath('key-32.png')
                },
                {
                    xtype: 'label',
                    cls: 'nx-usertoken-message',
                    html: 'User tokens provide an alternative mechanism to authenticate with Nexus without use of passwords.<br clear="both"/>'
                },
                {
                    xtype: 'fieldset',
                    title: 'Access',
                    autoHeight: true,
                    items: [
                        {
                            xtype: 'label',
                            html: 'A new user token will be created the first time it is accessed.<br/><br clear="both"/>',
                            cls: 'nx-usertoken-message'
                        },
                        {
                            xtype: 'nx-usertoken-auth-button',
                            text: 'Access User Token',
                            tooltip: 'Authenticate and access user token',
                            callback: {
                                scope: self,
                                fn: self.accessUserToken
                            }
                        }
                    ]
                },
                {
                    xtype: 'fieldset',
                    title: 'Reset',
                    autoHeight: true,
                    items: [
                        {
                            xtype: 'label',
                            html: 'Resetting your user token will invalidate the current token and force a new token to be created the next time accessed.<br/><br/>',
                            cls: 'nx-usertoken-message'
                        },
                        {
                            xtype: 'nx-usertoken-auth-button',
                            text: 'Reset User Token',
                            tooltip: 'Authenticate and reset user token',
                            callback: {
                                scope: self,
                                fn: self.resetUserToken
                            }
                        }
                    ]
                }
            ]
        });

        // Call super constructor
        self.constructor.superclass.constructor.apply(self, arguments);
    },

    getWaitMask: function() {
        var self = this;

        if (!self.waitMask) {
            self.waitMask = new Ext.LoadMask(self.getEl(), {
                msg: 'Please wait'
            });
        }
        return self.waitMask;
    },

    accessUserToken: function (authTicket) {
        var self = this;

        self.logDebug('Access user token');

        self.getWaitMask().show();

        Ext.Ajax.request({
            url: Nexus.usertoken.resourcePath('/current'),
            method: 'GET',
            scope: self,

            headers: {
                'X-NX-UserToken-AuthTicket': authTicket
            },

            callback: function() {
                self.getWaitMask().hide();
            },

            success: function(response) {
                var token, window;
                token = Ext.decode(response.responseText);
                window = new Nexus.usertoken.UserTokenWindow({
                    nameCode: token.nameCode,
                    passCode: token.passCode
                });
                window.show();
            }
        });
    },

    resetUserToken: function (authTicket) {
        var self = this;

        self.logDebug('Reset user token');

        self.getWaitMask().show();

        Ext.Ajax.request({
            url: Nexus.usertoken.resourcePath('/current'),
            method: 'DELETE',
            scope: self,

            headers: {
                'X-NX-UserToken-AuthTicket': authTicket
            },

            callback: function() {
                self.getWaitMask().hide();
            },

            success: function() {
                Nexus.usertoken.showMessage('Your user token has been reset');
            }
        });
    },

    shouldShow: function() {
        var p = Sonatype.lib.Permissions;
        return Nexus.usertoken.enabled && p.checkPermission('nexus:usertoken:current', p.CREATE, p.READ, p.DELETE)
    }
},

function() {
    var type = this;
    Nexus.profile.register(Nexus.usertoken.TITLE, type, ['user']);
});
